@@ -5,8 +5,8 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $DATE = '2014-12-05'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-04-25'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use Scalar::Util qw(blessed);
 use Log::Any::For::Package qw(add_logging_to_package);
@@ -123,7 +123,7 @@ Log::Any::For::Class - Add logging to class
 
 =head1 VERSION
 
-This document describes version 0.24 of Log::Any::For::Class (from Perl distribution Log-Any-For-Class), released on 2014-12-05.
+This document describes version 0.25 of Log::Any::For::Class (from Perl distribution Log-Any-For-Class), released on 2015-04-25.
 
 =head1 SYNOPSIS
 
@@ -155,11 +155,11 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<classes>* => I<array>
+=item * B<classes>* => I<array[str]>
 
 Classes to add logging to.
 
-=item * B<filter_methods> => I<array>
+=item * B<filter_methods> => I<array[str]>
 
 Filter methods to add logging to.
 
@@ -244,9 +244,7 @@ can also be set via environment C<LOG_SUB_RESULT>.
 
 =back
 
-Return value:
-
- (any)
+Return value:  (any)
 
 =head1 SEE ALSO
 
@@ -260,7 +258,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Log-Any-Fo
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Log-Any-For-Class>.
+Source repository is at L<https://github.com/sharyanto/perl-Log-Any-For-Class>.
 
 =head1 BUGS
 
@@ -276,7 +274,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
