@@ -1,7 +1,7 @@
 package Log::Any::For::Package;
 
-our $DATE = '2014-12-05'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-04-25'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010;
 use strict;
@@ -52,7 +52,7 @@ sub _default_precall_logger {
         # for Log4perl
         my $wd = $largs->{precall_wrapper_depth} // 2;
         local $Log::Log4perl::caller_depth = $Log::Log4perl::caller_depth +
-            $wd + $nest_level if $Log::{"Log4perl::"};
+            $wd + $nest_level if defined $Log::Log4perl::caller_depth;
 
         my $md     = $largs->{max_depth} // $default_max_depth;
         if ($md == -1 || $nest_level < $md) {
@@ -82,7 +82,7 @@ sub _default_postcall_logger {
         # for Log4perl
         my $wd = $largs->{postcall_wrapper_depth} // 2;
         local $Log::Log4perl::caller_depth = $Log::Log4perl::caller_depth +
-            $wd + $nest_level if $Log::{"Log4perl::"};
+            $wd + $nest_level if defined $Log::Log4perl::caller_depth;
 
         my $md     = $largs->{max_depth} // $default_max_depth;
         if ($md == -1 || $nest_level < $md) {
@@ -373,7 +373,7 @@ Log::Any::For::Package - Add logging to package
 
 =head1 VERSION
 
-This document describes version 0.24 of Log::Any::For::Package (from Perl distribution Log-Any-For-Class), released on 2014-12-05.
+This document describes version 0.25 of Log::Any::For::Package (from Perl distribution Log-Any-For-Class), released on 2015-04-25.
 
 =head1 SYNOPSIS
 
@@ -410,6 +410,42 @@ or, via import:
 
  % TRACE=1 perl -MLog::Any::App -MLog::Any::For::Package=-hook,1,.* ...
 
+=head1 FAQ
+
+=head2 How do I know that logging has been added to a package?
+
+Log::Any::For::Package logs a trace statement like this after it added logging
+to a package:
+
+ Added logging to package Foo (subs ["sub1","sub2",...])
+
+If you use L<Log::Any::App> to enable logging, you might not see this log
+message because it is produced during compile-time after C<use Foo>. To see this
+statement, you can do C<require Foo> instead or setup the logging at
+compile-time yourself instead of at the init-phase like what Log::Any::App is
+doing.
+
+=head1 ENVIRONMENT
+
+=head2 LOG_PACKAGE_INCLUDE_SUB_RE (str)
+
+=head2 LOG_PACKAGE_EXCLUDE_SUB_RE (str)
+
+=head2 LOG_SUB_ARGS (bool)
+
+=head2 LOG_SUB_RESULT (bool)
+
+=head1 CREDITS
+
+Some code portion taken from L<Devel::TraceMethods>.
+
+=head1 SEE ALSO
+
+L<Log::Any::For::Class>
+
+For some modules, use the appropriate Log::Any::For::*, for example:
+L<Log::Any::For::DBI>, L<Log::Any::For::LWP>.
+
 =head1 FUNCTIONS
 
 
@@ -429,7 +465,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<filter_subs> => I<code|re>
+=item * B<filter_subs> => I<re|code>
 
 Filter subroutines to add logging to.
 
@@ -454,7 +490,7 @@ Pass arguments to logger.
 
 This allows passing arguments to logger routine.
 
-=item * B<packages>* => I<array>
+=item * B<packages>* => I<array[str]>
 
 Packages to add logging to.
 
@@ -526,45 +562,7 @@ can also be set via environment C<LOG_SUB_RESULT>.
 
 =back
 
-Return value:
-
- (any)
-
-=head1 FAQ
-
-=head2 How do I know that logging has been added to a package?
-
-Log::Any::For::Package logs a trace statement like this after it added logging
-to a package:
-
- Added logging to package Foo (subs ["sub1","sub2",...])
-
-If you use L<Log::Any::App> to enable logging, you might not see this log
-message because it is produced during compile-time after C<use Foo>. To see this
-statement, you can do C<require Foo> instead or setup the logging at
-compile-time yourself instead of at the init-phase like what Log::Any::App is
-doing.
-
-=head1 ENVIRONMENT
-
-=head2 LOG_PACKAGE_INCLUDE_SUB_RE (str)
-
-=head2 LOG_PACKAGE_EXCLUDE_SUB_RE (str)
-
-=head2 LOG_SUB_ARGS (bool)
-
-=head2 LOG_SUB_RESULT (bool)
-
-=head1 CREDITS
-
-Some code portion taken from L<Devel::TraceMethods>.
-
-=head1 SEE ALSO
-
-L<Log::Any::For::Class>
-
-For some modules, use the appropriate Log::Any::For::*, for example:
-L<Log::Any::For::DBI>, L<Log::Any::For::LWP>.
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -572,7 +570,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Log-Any-Fo
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Log-Any-For-Class>.
+Source repository is at L<https://github.com/sharyanto/perl-Log-Any-For-Class>.
 
 =head1 BUGS
 
@@ -588,7 +586,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
